@@ -1,4 +1,3 @@
-#ident "$Id: mount_afs.c,v 1.3 2004/01/29 16:01:22 raven Exp $"
 /*
  * mount_afs.c
  *
@@ -10,10 +9,8 @@
 
 #include <stdio.h>
 #include <malloc.h>
-#include <errno.h>
 #include <fcntl.h>
 #include <unistd.h>
-#include <syslog.h>
 #include <string.h>
 #include <sys/param.h>
 #include <sys/types.h>
@@ -30,16 +27,27 @@ int mount_init(void **context)
 	return 0;
 }
 
-int mount_mount(const char *root, const char *name, int name_len,
+int mount_mount(struct autofs_point *ap, const char *root, const char *name, int name_len,
 		const char *what, const char *fstype, const char *options, void *context)
 {
-	char dest[PATH_MAX * 2];
+	/* PATH_MAX is allegedly longest path allowed */
+	char dest[PATH_MAX + 1];
+	size_t r_len = strlen(root);
+	size_t d_len = r_len + name_len + 2;
 
-	strcpy(dest, root);	/* Convert the name to a mount point. */
-	strncat(dest, "/", sizeof(dest));
-	strncat(dest, name, sizeof(dest));
+	if (d_len > PATH_MAX)
+		return 1;
 
-	debug(MODPREFIX "mounting AFS %s -> %s", dest, what);
+	/* Convert the name to a mount point. */
+	strcpy(dest, root);
+	strcat(dest, "/");
+	strcat(dest, name);
+
+	/* remove trailing slash (http://bugs.debian.org/141775) */
+	if (dest[strlen(dest)-1] == '/')
+	    dest[strlen(dest)-1] = '\0';
+
+	debug(ap->logopt, MODPREFIX "mounting AFS %s -> %s", dest, what);
 
 	return symlink(what, dest);	/* Try it.  If it fails, return the error. */
 }
